@@ -16,7 +16,7 @@ from tune_the_model.resource import (
 )
 
 __all__ = [
-    "model_one",
+    "tune_the_model",
     "set_api_key",
     "API_URL",
     "TuneTheModelException",
@@ -29,4 +29,4 @@ __all__ = [
     "tune_generator",
     "tune_classifier",
     "generate",
-]
\ No newline at end of file
+]
